==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/patientbaseplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>PatientBar</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="96"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="135"/>
        <source>Name, Secondname - firstname</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PatientSelector</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientselector.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientselector.ui" line="20"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>Patients</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="39"/>
        <source>Search by Name</source>
        <translation>Chercher par nom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="40"/>
        <source>Search by First name</source>
        <translation>Chercher par prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="41"/>
        <source>Search by Name and First name</source>
        <translation>Chercher par nom et prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="42"/>
        <source>Search by Date Of Birth</source>
        <translation>Chercher par date de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="44"/>
        <source>Type the name or second name of the patient</source>
        <translation>Saisissez le nom de naissance ou marital du patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="45"/>
        <source>Type the firstname of the patient</source>
        <translation>Saisissez le prénom du patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="46"/>
        <source>Type the name or second name followed by ; and the firstname</source>
        <translation>Saisissez le nom de naissance ou marital suivi du prénom du patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="47"/>
        <source>Type the date of birth (yyyy/MM/dd)</source>
        <translation>Saisissez la date de naissance (yyyy/MM/dd)</translation>
    </message>
</context>
<context>
    <name>Patients::IdentityPage</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="112"/>
        <source>Please enter the patient&apos;s identity.</source>
        <translation>Veuillez saisir l&apos;identité du patient.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="141"/>
        <source>Patient already exists</source>
        <translation>Le patient existe déjà</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="142"/>
        <source>A patient with the same names, gender and date of birth already exists. You can not create duplicates.</source>
        <translation>Un patient avec les mêmes noms, genre et date de naissance existe déjà. Vous ne pouvez pas créer de doublons.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="167"/>
        <source>You are about to create the following  patient: %1</source>
        <translation>Vous êtes sur le point de créer le patient %1</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="169"/>
        <source>Patients with the same names exist in the database.</source>
        <translation>Des patients avec les mêmes noms existent dans la base de données.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="171"/>
        <source>Do you really want to create this patient?</source>
        <translation>Voulez-vous réellement créer ce patient ?</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="173"/>
        <source>Patients of the same name exist</source>
        <translation>Des patients homonymes existent</translation>
    </message>
</context>
<context>
    <name>Patients::IdentityWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="272"/>
        <source>born on</source>
        <translation>né(e) le</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="286"/>
        <source>You must specify a birthname.</source>
        <translation>Vous devez spécifier un nom de naissance.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="287"/>
        <source>You can not create a patient without a birthname</source>
        <translation>Vous ne pouvez pas créer un patient sans nom de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="288"/>
        <source>No birthname</source>
        <translation>Pas de nom de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="292"/>
        <source>You must specify a first name.</source>
        <translation>Vous devez spécifier un prénom.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="293"/>
        <source>You can not create a patient without a first name</source>
        <translation>Vous ne pouvez pas créer un patient sans prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="294"/>
        <source>No firstname</source>
        <translation>Pas de prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="298"/>
        <source>You must specify a date of birth.</source>
        <translation>Vous devez spécifier une date de naissance.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="299"/>
        <source>You can not create a patient without a date of birth</source>
        <translation>Vous ne pouvez pas créer un patient sans date de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="300"/>
        <source>No date of birth</source>
        <translation>Pas de date de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="304"/>
        <source>You must specify a gender.</source>
        <translation>Vous devez spécifier un sexe.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="305"/>
        <source>You can not create a patient without a gender</source>
        <translation>Vous ne pouvez pas créer un patient sans sexe</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="306"/>
        <source>No gender</source>
        <translation>Pas de sexe</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="421"/>
        <source>Choose a photo</source>
        <translation>Choisissez une photographie</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityViewer</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="148"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="171"/>
        <source>Contact</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="20"/>
        <source>Identity</source>
        <translation>Identité</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="26"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="60"/>
        <source>Click to add/change the photo</source>
        <translation>Cliquez pour ajouter/modifier la photographie</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="73"/>
        <source>Birth name</source>
        <translation>Nom de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="99"/>
        <source>First name</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="141"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="86"/>
        <source>Second name</source>
        <translation>Nom marital</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="112"/>
        <source>Gender</source>
        <translation>Sexe</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="125"/>
        <source>Date of birth</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="147"/>
        <source>Street</source>
        <translation>Rue</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="157"/>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="170"/>
        <source>Zipcode</source>
        <translation>Code postal</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="183"/>
        <source>Country</source>
        <translation>Pays</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientActionHandler</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="149"/>
        <source>Fatal Error</source>
        <translation>Erreur fatale</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="149"/>
        <source>%1: Unable to retreive patients menu.</source>
        <translation>%1 : impossible de récupérer le menu patients.</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePreferencesPage</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.cpp" line="67"/>
        <source>Patient database preferences</source>
        <translation>Préférences pour la base de données patients</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePreferencesWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="20"/>
        <source>Patient selector</source>
        <translation>Sélectionneur de patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="26"/>
        <source>Use color to differentiate genders</source>
        <translation>Différentier les sexes par des couleurs différentes</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="33"/>
        <source>Select newly created patients</source>
        <translation>Sélectionner les patients nouvellement créés</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="56"/>
        <source>Patient bar</source>
        <translation>Barre patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="62"/>
        <source>Background color</source>
        <translation>Couleur de fond</translation>
    </message>
</context>
<context>
    <name>Patients::PatientBasePlugin</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbaseplugin.cpp" line="114"/>
        <location filename="../../plugins/patientbaseplugin/patientbaseplugin.cpp" line="170"/>
        <source>Initializing patients database plugin...</source>
        <translation>Initialisation de la base de données patients...</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbaseplugin.cpp" line="122"/>
        <source>Initializing patient database...</source>
        <translation>Initialisation de la base de données patients...</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbaseplugin.cpp" line="122"/>
        <source>Please wait</source>
        <translation>Veuillez patienter</translation>
    </message>
</context>
<context>
    <name>Patients::PatientCreatorWizard</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="64"/>
        <source>New Patient</source>
        <translation>Nouveau patient</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="81"/>
        <source>WARNING! You did not save this patient. If you continue without saving, all changes will be lost.</source>
        <translation>ATTENTION ! Vous n&apos;avez pas sauvegardé le patient. Si vous continuez sans sauvegarder, tous les changements seront perdus.</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="83"/>
        <source>Do you really want to close this dialog?</source>
        <translation>Voulez-vous réellement fermer ce dialogue ?</translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="84"/>
        <source>Patient not saved</source>
        <translation>Patient non sauvegardé</translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.8.0.orig.tar.gz: freemedforms-0.8.0/global_resources/translations/patientbaseplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>PatientBar</name>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Name, Secondname - firstname</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PatientSelector</name>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Patients</name>
    <message>
        <source>Search by Name</source>
        <translation>Chercher par nom</translation>
    </message>
    <message>
        <source>Search by First name</source>
        <translation>Chercher par prénom</translation>
    </message>
    <message>
        <source>Search by Name and First name</source>
        <translation>Chercher par nom et prénom</translation>
    </message>
    <message>
        <source>Search by Date Of Birth</source>
        <translation>Chercher par date de naissance</translation>
    </message>
    <message>
        <source>Type the name or second name of the patient</source>
        <translation>Saisissez le nom de naissance ou marital du patient</translation>
    </message>
    <message>
        <source>Type the firstname of the patient</source>
        <translation>Saisissez le prénom du patient</translation>
    </message>
    <message>
        <source>Type the name or second name followed by ; and the firstname</source>
        <translation>Saisissez le nom de naissance ou marital suivi du prénom du patient</translation>
    </message>
    <message>
        <source>Type the date of birth (yyyy/MM/dd)</source>
        <translation>Saisissez la date de naissance (yyyy/MM/dd)</translation>
    </message>
</context>
<context>
    <name>Patients::FilePhotoProvider</name>
    <message>
        <source>Choose a photo</source>
        <translation>Choisissez une photographie</translation>
    </message>
    <message>
        <source>Choose from file...</source>
        <translation>Sélectionnez depuis un fichier...</translation>
    </message>
</context>
<context>
    <name>Patients::IdentityPage</name>
    <message>
        <source>Please enter the patient&apos;s identity.</source>
        <translation>Veuillez saisir l&apos;identité du patient.</translation>
    </message>
    <message>
        <source>Patient already exists</source>
        <translation>Le patient existe déjà</translation>
    </message>
    <message>
        <source>A patient with the same names, gender and date of birth already exists. You can not create duplicates.</source>
        <translation>Un patient avec les mêmes noms, genre et date de naissance existe déjà. Vous ne pouvez pas créer de doublons.</translation>
    </message>
    <message>
        <source>You are about to create the following  patient: %1</source>
        <translation>Vous êtes sur le point de créer le patient %1</translation>
    </message>
    <message>
        <source>Patients with the same names exist in the database.</source>
        <translation>Des patients avec les mêmes noms existent dans la base de données.</translation>
    </message>
    <message>
        <source>Do you really want to create this patient?</source>
        <translation>Voulez-vous réellement créer ce patient ?</translation>
    </message>
    <message>
        <source>Patients of the same name exist</source>
        <translation>Des patients homonymes existent</translation>
    </message>
</context>
<context>
    <name>Patients::IdentityWidget</name>
    <message>
        <source>You must specify a birthname.</source>
        <translation>Vous devez spécifier un nom de naissance.</translation>
    </message>
    <message>
        <source>You can not create a patient without a birthname</source>
        <translation>Vous ne pouvez pas créer un patient sans nom de naissance</translation>
    </message>
    <message>
        <source>No birthname</source>
        <translation>Pas de nom de naissance</translation>
    </message>
    <message>
        <source>You must specify a first name.</source>
        <translation>Vous devez spécifier un prénom.</translation>
    </message>
    <message>
        <source>You can not create a patient without a first name</source>
        <translation>Vous ne pouvez pas créer un patient sans prénom</translation>
    </message>
    <message>
        <source>No firstname</source>
        <translation>Pas de prénom</translation>
    </message>
    <message>
        <source>You must specify a date of birth.</source>
        <translation>Vous devez spécifier une date de naissance.</translation>
    </message>
    <message>
        <source>You can not create a patient without a date of birth</source>
        <translation>Vous ne pouvez pas créer un patient sans date de naissance</translation>
    </message>
    <message>
        <source>No date of birth</source>
        <translation>Pas de date de naissance</translation>
    </message>
    <message>
        <source>You must specify a gender.</source>
        <translation>Vous devez spécifier un sexe.</translation>
    </message>
    <message>
        <source>You can not create a patient without a gender</source>
        <translation>Vous ne pouvez pas créer un patient sans sexe</translation>
    </message>
    <message>
        <source>No gender</source>
        <translation>Pas de sexe</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityViewer</name>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>photo</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityWidget</name>
    <message>
        <source>Identity</source>
        <translation>Identité</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <source>Click to add/change the photo</source>
        <translation>Cliquez pour ajouter/modifier la photographie</translation>
    </message>
    <message>
        <source>Birth name</source>
        <translation>Nom de naissance</translation>
    </message>
    <message>
        <source>First name</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Second name</source>
        <translation>Nom marital</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Sexe</translation>
    </message>
    <message>
        <source>Date of birth</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <source>Street</source>
        <translation>Rue</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <source>Zipcode</source>
        <translation>Code postal</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Pays</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientActionHandler</name>
    <message>
        <source>Fatal Error</source>
        <translation>Erreur fatale</translation>
    </message>
    <message>
        <source>%1: Unable to retreive patients menu.</source>
        <translation>%1 : impossible de récupérer le menu patients.</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePlugin</name>
    <message>
        <source>Initializing patients database plugin...</source>
        <translation>Initialisation de la base de données patients...</translation>
    </message>
    <message>
        <source>Initializing patient database...</source>
        <translation>Initialisation de la base de données patients...</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Veuillez patienter</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePreferencesPage</name>
    <message>
        <source>Patient database preferences</source>
        <translation>Préférences pour la base de données patients</translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePreferencesWidget</name>
    <message>
        <source>Patient selector</source>
        <translation>Sélectionneur de patient</translation>
    </message>
    <message>
        <source>Use color to differentiate genders</source>
        <translation>Différentier les sexes par des couleurs différentes</translation>
    </message>
    <message>
        <source>Select newly created patients</source>
        <translation>Sélectionner les patients nouvellement créés</translation>
    </message>
    <message>
        <source>Patient bar</source>
        <translation>Barre patient</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Background color:</source>
        <translation>Couleur de fond :</translation>
    </message>
    <message>
        <source>Patient photo</source>
        <translation>Photographie du patient</translation>
    </message>
    <message>
        <source>Default photo source:</source>
        <translation>Source par défaut pour les photographies :</translation>
    </message>
</context>
<context>
    <name>Patients::PatientCreatorWizard</name>
    <message>
        <source>New Patient</source>
        <translation>Nouveau patient</translation>
    </message>
    <message>
        <source>WARNING! You did not save this patient. If you continue without saving, all changes will be lost.</source>
        <translation>ATTENTION ! Vous n&apos;avez pas sauvegardé le patient. Si vous continuez sans sauvegarder, tous les changements seront perdus.</translation>
    </message>
    <message>
        <source>Do you really want to close this dialog?</source>
        <translation>Voulez-vous réellement fermer ce dialogue ?</translation>
    </message>
    <message>
        <source>Patient not saved</source>
        <translation>Patient non sauvegardé</translation>
    </message>
</context>
<context>
    <name>Patients::PixmapButton</name>
    <message>
        <source>Delete photo</source>
        <translation>Supprimer la photographie</translation>
    </message>
</context>
<context>
    <name>Patients::UrlPhotoDialog</name>
    <message>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;URL:</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Error downloading the file.&lt;br/&gt;Please check the correctness of the URL.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Une erreur est survenue durant le téléchargement du fichier.&lt;br/&gt;Veuillez vérifier l&apos;adresse du fichier.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;The picture must be in one of the following formats: &lt;span style=&quot; color:#006400;&quot;&gt;PNG, JPG, GIF&lt;/span&gt;.&lt;br/&gt;Please be sure that you have the permission to use this picture.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;L&apos;image doit être dans un des formats suivants : &lt;span style=&quot; color:#006400;&quot;&gt;PNG, JPG, GIF&lt;/span&gt;.&lt;br/&gt;Veuillez vous assurez que vous disposez des permissions adéquates pour utiliser cette image.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
</TS>
